
# 配置自定义的模型参数

请手动修改位于 `data/cmd_config.json` 下的配置文件。

找到 `provider`，并找到你想要修改的提供商的模型配置：

![alt text](https://files.astrbot.app/docs/source/images/model-config/image-2.png)

然后在 `model_config` 中添加新的参数即可。

具体的参数请参看对应的提供商的文档。
